@@ -119,11 +119,11 @@ log = get_brace_style_log_with_null_handler(__name__)
 
 # Not in SQL Server (though in MySQL):
 #
-# don't think so: BINARY; http://gilfster.blogspot.co.uk/2005/08/case-sensitivity-in-mysql.html  # noqa
-# DISTINCTROW: no; https://stackoverflow.com/questions/8562136/distinctrow-equivalent-in-sql-server  # noqa
-# DIV/MOD: not in SQL Server; use / and % respectively; https://msdn.microsoft.com/en-us/library/ms190279.aspx  # noqa
-# PARTITION: not in SELECT? - https://msdn.microsoft.com/en-us/library/ms187802.aspx  # noqa
-# XOR: use ^ instead; https://stackoverflow.com/questions/5411619/t-sql-xor-operator  # noqa
+# don't think so: BINARY; http://gilfster.blogspot.co.uk/2005/08/case-sensitivity-in-mysql.html  # noqa: E501
+# DISTINCTROW: no; https://stackoverflow.com/questions/8562136/distinctrow-equivalent-in-sql-server  # noqa: E501
+# DIV/MOD: not in SQL Server; use / and % respectively; https://msdn.microsoft.com/en-us/library/ms190279.aspx  # noqa: E501
+# PARTITION: not in SELECT? - https://msdn.microsoft.com/en-us/library/ms187802.aspx  # noqa: E501
+# XOR: use ^ instead; https://stackoverflow.com/questions/5411619/t-sql-xor-operator  # noqa: E501
 
 # Definitely part of SQL Server:
 CHECKSUM_AGG = sql_keyword("CHECKSUM_AGG")
@@ -231,7 +231,7 @@ ZONE
     # ... who thought "END-EXEC" was a good one?
 
     # Then some more:
-    # - WITH ROLLUP: https://technet.microsoft.com/en-us/library/ms189305(v=sql.90).aspx  # noqa
+    # - WITH ROLLUP: https://technet.microsoft.com/en-us/library/ms189305(v=sql.90).aspx  # noqa: E501
     # - SOUNDEX: https://msdn.microsoft.com/en-us/library/ms187384.aspx
     rnc_extra_sql_server_keywords = """
 ROLLUP
@@ -305,7 +305,7 @@ SOUNDEX
     ).setName("column_spec")
     # I'm unsure if SQL Server allows keywords in the parts after dots, like
     # MySQL does.
-    # - https://stackoverflow.com/questions/285775/how-to-deal-with-sql-column-names-that-look-like-sql-keywords  # noqa
+    # - https://stackoverflow.com/questions/285775/how-to-deal-with-sql-column-names-that-look-like-sql-keywords  # noqa: E501
 
     bind_parameter = Literal("?")
 
@@ -317,7 +317,7 @@ SOUNDEX
     function_call = Combine(function_name + LPAR) + argument_list + RPAR
 
     # Not supported: index hints
-    # ... https://stackoverflow.com/questions/11016935/how-can-i-force-a-query-to-not-use-a-index-on-a-given-table  # noqa
+    # ... https://stackoverflow.com/questions/11016935/how-can-i-force-a-query-to-not-use-a-index-on-a-given-table  # noqa: E501
 
     # -----------------------------------------------------------------------------
     # CASE
@@ -446,9 +446,7 @@ SOUNDEX
         + DISTINCT
         + expr
         + RPAR
-        | Combine(  # special aggregate function  # noqa
-            aggregate_function + LPAR
-        )
+        | Combine(aggregate_function + LPAR)  # special aggregate function
         + expr
         + RPAR
         | expr
@@ -641,13 +639,13 @@ def pyparsing_bugtest_delimited_list_combine(fix_problem: bool = True) -> None:
     word_list_combine = delimitedList(word, combine=True)
     print(
         word_list_no_combine.parseString("one, two", parseAll=True)
-    )  # ['one', 'two']  # noqa
+    )  # ['one', 'two']
     print(
         word_list_no_combine.parseString("one,two", parseAll=True)
-    )  # ['one', 'two']  # noqa
+    )  # ['one', 'two']
     print(
         word_list_combine.parseString("one, two", parseAll=True)
-    )  # ['one']: ODD ONE OUT  # noqa
+    )  # ['one']: ODD ONE OUT
     print(
         word_list_combine.parseString("one,two", parseAll=True)
-    )  # ['one,two']  # noqa
+    )  # ['one,two']
