@@ -64,7 +64,7 @@ def is_sqlserver(engine: "Engine") -> bool:
     return dialect_name == SqlaDialectName.SQLSERVER
 
 
-def get_sqlserver_product_version(engine: "Engine") -> Tuple[int]:
+def get_sqlserver_product_version(engine: "Engine") -> Tuple[int, ...]:
     """
     Gets SQL Server version information.
 
@@ -75,7 +75,7 @@ def get_sqlserver_product_version(engine: "Engine") -> Tuple[int]:
         from sqlalchemy import create_engine
 
         url = "mssql+pyodbc://USER:PASSWORD@ODBC_NAME"
-        engine = create_engine(url)
+        engine = create_engine(url, future=True)
         dialect = engine.dialect
         vi = dialect.server_version_info
 
@@ -104,13 +104,14 @@ def get_sqlserver_product_version(engine: "Engine") -> Tuple[int]:
         "instances."
     )
     sql = "SELECT CAST(SERVERPROPERTY('ProductVersion') AS VARCHAR)"
-    rp = engine.execute(sql)  # type: Result
-    row = rp.fetchone()
+    with engine.begin() as connection:
+        rp = connection.execute(sql)  # type: Result
+        row = rp.fetchone()
     dotted_version = row[0]  # type: str  # e.g. '12.0.5203.0'
     return tuple(int(x) for x in dotted_version.split("."))
 
 
-# https://www.mssqltips.com/sqlservertip/1140/how-to-tell-what-sql-server-version-you-are-running/  # noqa
+# https://www.mssqltips.com/sqlservertip/1140/how-to-tell-what-sql-server-version-you-are-running/  # noqa: E501
 SQLSERVER_MAJOR_VERSION_2000 = 8
 SQLSERVER_MAJOR_VERSION_2005 = 9
 SQLSERVER_MAJOR_VERSION_2008 = 10
@@ -129,3 +130,16 @@ def is_sqlserver_2008_or_later(engine: "Engine") -> bool:
         return False
     version_tuple = get_sqlserver_product_version(engine)
     return version_tuple >= (SQLSERVER_MAJOR_VERSION_2008,)
+
+
+# =============================================================================
+# Helper functions for Databricks
+# =============================================================================
+
+
+def is_databricks(engine: "Engine") -> bool:
+    """
+    Is the SQLAlchemy :class:`Engine` a Databricks database?
+    """
+    dialect_name = get_dialect_name(engine)
+    return dialect_name == SqlaDialectName.DATABRICKS
